==> dokuwiki-2013.05.10.tgz: dokuwiki/lib/plugins/acl/lang/el/lang.php <==
<?php
/**
 * Greek language file
 *
 * Based on DokuWiki Version rc2007-05-24 english language file
 * Original english language file contents included for reference
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Andreas Gohr <andi@splitbrain.org>
 * @author Anika Henke <anika@selfthinker.org>
 * @author Matthias Grimm <matthiasgrimm@users.sourceforge.net>
 * @author Thanos Massias <tm@thriasio.gr>
 * @author Αθανάσιος Νταής <homunculus@wana.gr>
 * @author Konstantinos Koryllos <koryllos@gmail.com>
 * @author George Petsagourakis <petsagouris@gmail.com>
 * @author Petros Vidalis <pvidalis@gmail.com>
 * @author Vasileios Karavasilis vasileioskaravasilis@gmail.com
 */
$lang['admin_acl']             = 'Διαχείριση Δικαιωμάτων Πρόσβασης';
$lang['acl_group']             = 'Ομάδα';
$lang['acl_user']              = 'Χρήστης';
$lang['acl_perms']             = 'Δικαιώματα για';
$lang['page']                  = 'Σελίδα';
$lang['namespace']             = 'Φάκελος';
$lang['btn_select']            = 'Επιλογή';
$lang['p_user_id']             = 'Ο χρήστης <b class="acluser">%s</b> έχει τα ακόλουθα δικαιώματα πρόσβασης στην σελίδα <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'Ο χρήστης <b class="acluser">%s</b> έχει τα ακόλουθα δικαιώματα πρόσβασης στον φάκελο <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Τα μέλη της ομάδας <b class="aclgroup">%s</b> έχουν τα ακόλουθα δικαιώματα πρόσβασης στην σελίδα <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Τα μέλη της ομάδας <b class="aclgroup">%s</b> έχουν τα ακόλουθα δικαιώματα πρόσβασης στον φάκελο <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Παρακαλώ <b>δώστε ένα όνομα χρήστη ή ομάδας χρηστών</b> στην παραπάνω μορφή για να δείτε τα αντίστοιχα δικαιώματα πρόσβασης για την σελίδα <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Παρακαλώ <b>δώστε ένα όνομα χρήστη ή ομάδας χρηστών</b> στην παραπάνω μορφή για να δείτε τα αντίστοιχα δικαιώματα πρόσβασης για τον φάκελο <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'Σημείωση: Αυτά τα διακαιώματα χρήσης δεν ορίστηκαν άμεσα αλλά κληρονομήθηκαν από άλλες ομάδες χρηστών ή φακέλους σε υψηλότερο επίπεδο.';
$lang['p_isadmin']             = 'Σημείωση: Η επιλεγμένη ομάδα χρηστών ή χρήστης έχει πάντα πλήρη διακαιώματα πρόσβασης διότι είναι δηλωμένος σαν υπερχρήστης (superuser).';
$lang['p_include']             = 'Τα υψηλότερα δικαιώματα πρόσβασης περιλαμβάνουν τα χαμηλότερα. Τα δικαιώματα για Δημιουργία, Φόρτωση και Διαγραφή αφορούν μόνο φακέλους και όχι σελίδες. ';
$lang['current']               = 'Τρέχοντες κανόνες Λίστας Δικαιωμάτων Πρόσβασης - ACL';
$lang['where']                 = 'Σελίδα/Φάκελος';
$lang['who']                   = 'Χρήστης/Ομάδα χρηστών';
$lang['perm']                  = 'Δικαιώματα πρόσβασης';
$lang['acl_perm0']             = 'Κανένα';
$lang['acl_perm1']             = 'Ανάγνωση';
$lang['acl_perm2']             = 'Τροποποίηση';
$lang['acl_perm4']             = 'Δημιουργία';
$lang['acl_perm8']             = 'Φόρτωση';
$lang['acl_perm16']            = 'Διαγραφή';
$lang['acl_new']               = 'Προσθήκη νέας εγγραφής';
$lang['acl_mod']               = 'Τροποποίηση εγγραφής';

==> dokuwiki-2018.04.22ap2.tgz: dokuwiki/lib/plugins/acl/lang/el/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Andreas Gohr <andi@splitbrain.org>
 * @author Anika Henke <anika@selfthinker.org>
 * @author Matthias Grimm <matthiasgrimm@users.sourceforge.net>
 * @author Thanos Massias <tm@thriasio.gr>
 * @author Αθανάσιος Νταής <homunculus@wana.gr>
 * @author Konstantinos Koryllos <koryllos@gmail.com>
 * @author George Petsagourakis <petsagouris@gmail.com>
 * @author Petros Vidalis <pvidalis@gmail.com>
 * @author Vasileios Karavasilis vasileioskaravasilis@gmail.com
 */
$lang['admin_acl']             = 'Διαχείριση Δικαιωμάτων Πρόσβασης';
$lang['acl_group']             = 'Ομάδα:';
$lang['acl_user']              = 'Χρήστης:';
$lang['acl_perms']             = 'Δικαιώματα για';
$lang['page']                  = 'Σελίδα';
$lang['namespace']             = 'Φάκελος';
$lang['btn_select']            = 'Επιλογή';
$lang['p_user_id']             = 'Ο χρήστης <b class="acluser">%s</b> έχει τα ακόλουθα δικαιώματα πρόσβασης στην σελίδα <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'Ο χρήστης <b class="acluser">%s</b> έχει τα ακόλουθα δικαιώματα πρόσβασης στον φάκελο <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Τα μέλη της ομάδας <b class="aclgroup">%s</b> έχουν τα ακόλουθα δικαιώματα πρόσβασης στην σελίδα <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Τα μέλη της ομάδας <b class="aclgroup">%s</b> έχουν τα ακόλουθα δικαιώματα πρόσβασης στον φάκελο <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Παρακαλώ <b>δώστε ένα όνομα χρήστη ή ομάδας χρηστών</b> στην παραπάνω μορφή για να δείτε τα αντίστοιχα δικαιώματα πρόσβασης για την σελίδα <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Παρακαλώ <b>δώστε ένα όνομα χρήστη ή ομάδας χρηστών</b> στην παραπάνω μορφή για να δείτε τα αντίστοιχα δικαιώματα πρόσβασης για τον φάκελο <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'Σημείωση: Αυτά τα διακαιώματα χρήσης δεν ορίστηκαν άμεσα αλλά κληρονομήθηκαν από άλλες ομάδες χρηστών ή φακέλους σε υψηλότερο επίπεδο.';
$lang['p_isadmin']             = 'Σημείωση: Η επιλεγμένη ομάδα χρηστών ή χρήστης έχει πάντα πλήρη διακαιώματα πρόσβασης διότι είναι δηλωμένος σαν υπερχρήστης (superuser).';
$lang['p_include']             = 'Τα υψηλότερα δικαιώματα πρόσβασης περιλαμβάνουν τα χαμηλότερα. Τα δικαιώματα για Δημιουργία, Φόρτωση και Διαγραφή αφορούν μόνο φακέλους και όχι σελίδες. ';
$lang['current']               = 'Τρέχοντες κανόνες Λίστας Δικαιωμάτων Πρόσβασης - ACL';
$lang['where']                 = 'Σελίδα/Φάκελος';
$lang['who']                   = 'Χρήστης/Ομάδα χρηστών';
$lang['perm']                  = 'Δικαιώματα πρόσβασης';
$lang['acl_perm0']             = 'Κανένα';
$lang['acl_perm1']             = 'Ανάγνωση';
$lang['acl_perm2']             = 'Τροποποίηση';
$lang['acl_perm4']             = 'Δημιουργία';
$lang['acl_perm8']             = 'Φόρτωση';
$lang['acl_perm16']            = 'Διαγραφή';
$lang['acl_new']               = 'Προσθήκη νέας εγγραφής';
$lang['acl_mod']               = 'Τροποποίηση εγγραφής';
